@@ -1,20 +1,33 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2002 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "secrecy.h"
 
-#include <KLocalizedString>
+#include <klocalizedstring.h>
 
-#include <QDataStream>
-#include <QSharedData>
+#include <QtCore/QDataStream>
+#include <QtCore/QSharedData>
 
 using namespace KContacts;
 
-class Q_DECL_HIDDEN Secrecy::PrivateData : public QSharedData
+class Secrecy::PrivateData : public QSharedData
 {
 public:
     PrivateData()
@@ -42,7 +55,9 @@ Secrecy::Secrecy(const Secrecy &other)
 {
 }
 
-Secrecy::~Secrecy() = default;
+Secrecy::~Secrecy()
+{
+}
 
 Secrecy &Secrecy::operator=(const Secrecy &other)
 {
@@ -109,9 +124,11 @@ QString Secrecy::typeLabel(Type type)
 
 QString Secrecy::toString() const
 {
-    QString str = QLatin1String("Secrecy {\n");
-    str += QStringLiteral("  Type: %1\n").arg(typeLabel(d->mType));
-    str += QLatin1String("}\n");
+    QString str;
+
+    str += QString::fromLatin1("Secrecy {\n");
+    str += QString::fromLatin1("  Type: %1\n").arg(typeLabel(d->mType));
+    str += QString::fromLatin1("}\n");
 
     return str;
 }
